@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2016-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -16,8 +16,6 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """elasticsearch search views"""
-from six import text_type as unicode
-
 from elasticsearch.exceptions import NotFoundError
 from elasticsearch_dsl import FacetedSearch, TermsFacet, DateHistogramFacet
 from bs4 import BeautifulSoup
@@ -118,9 +116,9 @@ class CWFacetedSearch(FacetedSearch):
 
 class ElasticSearchView(StartupView):
     __regid__ = "esearch"
-    previous_link = u" &lt; "
-    next_link = u" &gt; "
-    middle_link = u" &middot; " * 3
+    previous_link = " &lt; "
+    next_link = " &gt; "
+    middle_link = " &middot; " * 3
     title = _("Search")
     default_items_per_page = 10
 
@@ -157,33 +155,33 @@ class ElasticSearchView(StartupView):
         if "debug-es" in self._cw.form:
             import json
 
-            self.w(u"<pre>")
-            self.w(unicode(json.dumps(search._s.to_dict(), indent=2)))
-            self.w(u"</pre>")
-            self.w(u"<br/>")
+            self.w("<pre>")
+            self.w(json.dumps(search._s.to_dict(), indent=2))
+            self.w("</pre>")
+            self.w("<br/>")
         try:
             response = search.execute()
             if "debug-es" in self._cw.form:
                 import json
 
-                self.w(u"<pre>")
-                self.w(unicode(json.dumps(response.to_dict(), indent=2)))
-                self.w(u"</pre>")
-                self.w(u"<br/>")
+                self.w("<pre>")
+                self.w(json.dumps(response.to_dict(), indent=2))
+                self.w("</pre>")
+                self.w("<br/>")
             return response
         except NotFoundError:
-            self.w(u"index not found in elasticsearch")
+            self.w("index not found in elasticsearch")
             return
 
     def call(self, **kwargs):
         # TODO if no ES configuration, redirect or display warning
         self.render_search_comp()
         query_string = self._cw.form.get("q", self._cw.form.get("search", ""))
-        self.w(u"<h1>%s</h1>" % self._cw._(self.title))
+        self.w("<h1>%s</h1>" % self._cw._(self.title))
         response = self.do_search(query_string)
         if response.hits.total.value:
-            self.w(u"<h2>Resultats pour : <em>%s</em></h2>" % xml_escape(query_string))
-            self.w(u"Resultats: %s" % response.hits.total.value)
+            self.w("<h2>Resultats pour : <em>%s</em></h2>" % xml_escape(query_string))
+            self.w("Resultats: %s" % response.hits.total.value)
             if hasattr(response, "facets"):
                 self.display_facets(response)
         self.display_results(response)
@@ -214,11 +212,11 @@ class ElasticSearchView(StartupView):
         """
         Display results obtained from elasticsearch
         """
-        self.w(u'<div id="main-center" class="col-xs-10" role="main">')
+        self.w('<div id="main-center" class="col-xs-10" role="main">')
         self.pagination(response)
-        self.w(u"<ul>")
+        self.w("<ul>")
         for result in response:
-            self.w(u"<li>")
+            self.w("<li>")
             infos = result.to_dict()
             infos["_score"] = result.meta.score
             infos["keys"] = result.to_dict().keys()
@@ -229,21 +227,21 @@ class ElasticSearchView(StartupView):
             )
             self.customize_infos(infos)
             try:
-                self.w(u'<a href="%(url)s">%(title)s</a> (%(_score).2f)<br/>' % (infos))
+                self.w('<a href="%(url)s">%(title)s</a> (%(_score).2f)<br/>' % (infos))
                 if self._cw.form.get("debug-es"):
-                    self.w(u" [%(keys)s] <br/>" % infos)
+                    self.w(" [%(keys)s] <br/>" % infos)
             except KeyError:
-                self.w(u"Missing key in : %s" % infos.keys())
+                self.w("Missing key in : %s" % infos.keys())
             try:
                 for fragment in result.meta.highlight.content:
-                    self.w(u"... %s" % BeautifulSoup(fragment, "lxml").get_text())
-                    self.w(u" ... <br/>")
+                    self.w("... %s" % BeautifulSoup(fragment, "lxml").get_text())
+                    self.w(" ... <br/>")
             except AttributeError:
                 pass
-            self.w(u"</li>")
-        self.w(u"</ul>")
+            self.w("</li>")
+        self.w("</ul>")
         self.pagination(response)
-        self.w(u"</div>")
+        self.w("</div>")
 
     def customize_infos(self, infos):
         """
@@ -342,7 +340,7 @@ class ElasticSearchView(StartupView):
         Generate HTML for facets
         """
         self.w(
-            u"""<aside id="aside-main-left" class="col-xs-2 cwjs-aside">
+            """<aside id="aside-main-left" class="col-xs-2 cwjs-aside">
                    <div class="panel panel-default contextFreeBox facet_filterbox">
                       <div class="panel-heading">
                          <div class="panel-title">Facettes</div>
@@ -353,12 +351,12 @@ class ElasticSearchView(StartupView):
             url_params = self._cw.form.copy()
             if "page" in url_params:
                 del url_params["page"]
-            self.w(u'<div class="facetBody vocabularyFacet">')
-            self.w(u'<div class="facetTitle">{}</div>'.format(attribute))
+            self.w('<div class="facetBody vocabularyFacet">')
+            self.w('<div class="facetTitle">{}</div>'.format(attribute))
             for (tag, count, selected) in response.facets[attribute]:
                 # facetValueSelected / facetValueDisabled in class
                 facet_item = (
-                    u'<div class="facetValue facetCheckBox">'
+                    '<div class="facetValue facetCheckBox">'
                     "    <span>"
                     '      <a href="{}">{} {}</a>'
                     "    </span>"
@@ -373,5 +371,5 @@ class ElasticSearchView(StartupView):
                     selected and '<div class="facet-active">{}</div>'.format(tag) or tag
                 )
                 self.w(facet_item.format(url, content, count))
-            self.w(u"</div>")
-        self.w(u"</div></aside>")
+            self.w("</div>")
+        self.w("</div></aside>")
