@@ -27,7 +27,7 @@ class IndexHookTC(testlib.CubicWebTC):
         with self.admin_access.cnx() as cnx:
             indexer = cnx.vreg["es"].select("indexer", cnx)
             ce = cnx.create_entity
-            p = ce("Person", age=12, name=u"Jean")
+            p = ce("Person", age=12, name="Jean")
             cnx.commit()
             es = indexer.get_connection()
             self.assertTrue(es.index.called)
